---
QUILL: usaf_memo
letterhead_title: TERRAN DOMINION
letterhead_caption:
  - Raynor's Raiders
date: 2504-10-05
memo_for:
  - DOMINION/HQ
  - PROTOSS/FLEET
memo_from:
  - RAIDER/CC
  - Raynor's Raiders
  - Hyperion Battlecruiser
  - Sector 7G
subject: Zerg Swarm Threat Assessment
references:
  - Dominion Directive 47, 15 Aug 2504, Swarm Protocols
cc:
  - Captain Matt Horner, RAIDER/NAV
distribution:
  - Raynor's Raiders
  - Dominion Forces
  - Protoss Expeditionary Fleet
attachments:
  - Zerg Intel Report, 05 Oct 2504
signature_block:
  - JIM RAYNOR, Commander, Raynor's Raiders
tag_line: Raiders Roll
classification: SECRET//FICTIONAL
---

The `usaf_memo` Quill automatically numbers paragraphs. Top-level paragraphs like this one are automatically numbered 1., 2., etc.

- Use bullets for hierarchical paragraph nesting.
  - Up to five levels are supported.

**Section Titles** Do NOT use markdown headings. If you want to title sections, use bold text in-line with the paragraph. Never include a section title on its own line. Nest section children with bullets.